@@ -11,4 +11,4 @@ Example:
 'hello world'
 '''
 
-from base92.base92 import encode, decode, b92encode, b92decode
+from base92 import encode, decode, b92encode, b92decode, __version__
